@@ -34,22 +34,15 @@ class ComboBox : public QComboBox
 public:
     enum Move {NoMove=0 , MoveUp , MoveDown , MoveFirst , MoveLast};
 
-    ComboBox (QWidget *parent = nullptr) :
-        QComboBox (parent), hasPopup_ (false) {}
+    ComboBox (QWidget *parent = nullptr);
     ~ComboBox() {}
 
-    bool hasPopup() const;
-    void showPopup() override;
-    void hidePopup() override;
-
 signals:
     void moveInHistory (int move);
 
 protected:
     void keyPressEvent (QKeyEvent *event) override;
-
-private:
-    bool hasPopup_;
+    bool eventFilter (QObject *watched, QEvent *event) override;
 };
 
 class SearchBar : public QFrame
@@ -70,8 +63,6 @@ public:
     bool matchWhole() const;
     bool matchRegex() const;
 
-    bool hasPopup() const;
-
     void updateShortcuts (bool disable);
 
 signals:
